@@ -195,25 +195,34 @@ pub fn make_call_stmt(handle: Ident) -> Stmt {
 pub fn make_call_expr(handle: Ident) -> Expr {
     Expr::Call(CallExpr {
         span: DUMMY_SP,
-        callee: ExprOrSuper::Expr(Box::new(Expr::Ident(handle))),
+        callee: Callee::Expr(Box::new(Expr::Ident(handle))),
         args: Vec::new(),
         type_args: None,
     })
 }
 
 pub fn is_import_or_require(expr: &Expr) -> bool {
-    if let Expr::Call(CallExpr {
-        callee: ExprOrSuper::Expr(expr),
-        ..
-    }) = expr
-    {
-        if let Expr::Ident(ident) = expr.as_ref() {
-            if ident.sym.contains("require") || ident.sym.contains("import") {
-                return true;
+    match expr {
+        Expr::Call(CallExpr {
+            callee: Callee::Expr(expr),
+            ..
+        }) => {
+            if let Expr::Ident(ident) = expr.as_ref() {
+                if ident.sym.contains("require") {
+                    true
+                } else {
+                    false
+                }
+            } else {
+                false
             }
         }
+        Expr::Call(CallExpr {
+            callee: Callee::Import(_),
+            ..
+        }) => true,
+        _ => false,
     }
-    false
 }
 
 pub struct UsedInJsx(AHashSet<JsWord>);
@@ -224,16 +233,13 @@ impl Visit for UsedInJsx {
     fn visit_call_expr(&mut self, n: &CallExpr) {
         n.visit_children_with(self);
 
-        if let ExprOrSuper::Expr(expr) = &n.callee {
+        if let Callee::Expr(expr) = &n.callee {
             let ident = match expr.as_ref() {
                 Expr::Ident(ident) => ident,
-                Expr::Member(MemberExpr { prop, .. }) => {
-                    if let Expr::Ident(ident) = prop.as_ref() {
-                        ident
-                    } else {
-                        return;
-                    }
-                }
+                Expr::Member(MemberExpr {
+                    prop: MemberProp::Ident(ident),
+                    ..
+                }) => ident,
                 _ => return,
             };
             if matches!(
